/**
 * @file
 * Datalist clear button handling.
 */
(function () {
  'use strict';

  /**
   * Drupal behavior.
   */
  Drupal.behaviors.datalist = {
    attach: function (context) {
      const datalistsClear = document.querySelectorAll('.form-type--datalist .clear');
      const datalistsInput = document.querySelectorAll('.form-type--datalist input');
      if (datalistsClear.length === 0) {
        return;
      }

      datalistsInput.forEach(dataListInput => {
        Drupal.behaviors.datalist.toggleClearIfNotEmpty(dataListInput);

        // Chrome fills in input later on when going back.
        dataListInput.addEventListener('focus', function(e) {
          const dataListInput = e.target;
          Drupal.behaviors.datalist.toggleClearIfNotEmpty(dataListInput);
        });

        dataListInput.addEventListener('input', function(e) {
          const value = e.target.value;
          let clear_button = e.currentTarget.parentElement.querySelector('.clear');

          if (!value || value === '') {
            clear_button.classList.add('not-visible');
            clear_button.setAttribute('tabIndex', '-1');
          } else {
            if (!clear_button.classList.contains('visible')) {
              clear_button.classList.add('visible');
              clear_button.classList.remove('not-visible');
              clear_button.setAttribute('tabIndex', '0');
            }
          }
        });
      });

      datalistsClear.forEach(datalistClear => {
        datalistClear.addEventListener('click', function (e) {
          e.preventDefault();

          e.currentTarget.classList.remove('visible');
          e.currentTarget.classList.add('not-visible');

          let input = e.currentTarget.parentElement.querySelector('input');
          input.value = '';
          input.dispatchEvent(new Event("input", { bubbles: true }));
          input.dispatchEvent(new Event("change", { bubbles: true }));

          input.focus();
        });
      })
    },
    toggleClearIfNotEmpty: function(dataListInput) {
      if (dataListInput.value !== '') {
        let clear_button = dataListInput.parentElement.querySelector('.clear');
        clear_button.classList.add('visible');
        clear_button.classList.remove('not-visible');
      }
    }
  };

})();
